##
##  OpenPKG Tool Chain
##  Copyright (c) 2000-2005 OpenPKG Foundation e.V. <http://openpkg.net/>
##  Copyright (c) 2000-2005 Ralf S. Engelschall <http://engelschall.com/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##
##  api/OpenPKG/Obj.pm: API Base Object Class
##

package OpenPKG::Obj;

require 5;
require Exporter;

@ISA       = qw(Exporter);
@EXPORT_OK = qw(new destroy DESTROY dump);

sub new ($) {
    my $proto = shift;
    my $class = ref($proto) || $proto;
    my $self = {};
    bless ($self, $class);
    return $self;
}

sub destroy ($) {
    my $self = shift;
    return;
}

sub DESTROY ($) {
    my $self = shift;
    $self->destroy;
    return;
}

sub dump ($;$) {
    my $self = shift;
    my $name = shift || "xxx";
    eval {
        use Data::Dumper;
    };
    my $d = new Data::Dumper ([$self], [$name]);
    $d->Indent(1);
    $d->Purity(1);
    $d->Terse(0);
    $d->Deepcopy(0);
    my $dump = "# " . ref($self) . " object dump:\n";
    $dump .= $d->Dump();
    return $dump;
}

1;

__END__

=pod

=head1 NAME

B<OpenPKG::Obj> - Base Object Class

=head1 DESCRIPTION

B<OpenPKG::Obj> is the Base Object class in the OpenPKG Tool Chain Perl
API. It provides the base framework of all B<OpenPKG:*> classes. It is
not intended for direct use. Instead all other classes are derived from
it.

=head1 METHODS

=over 4

=item C<$obj = >B<new>C< OpenPKG::Obj;>

Create new OpenPKG::Obj object C<$obj>.

=item C<$obj-E<gt>>B<destroy>C<();>

Destroy object C<$obj>.

=item C<$obj-E<gt>>B<dump>C<(>[C<$name>]C<);>

Dump the internal state of object C<$obj>
in Data::Dumper(3) syntax. The default
assignment variable in the output is named
"C<xxx>" if no particular C<$name> is specified.

=head1 SEE ALSO

L<OpenPKG(3)>.

=head1 AUTHOR

The OpenPKG Project E<lt>http://www.openpkg.org/E<gt>

=cut

